@@ -7,15 +7,15 @@ class schema:
     """Inspect the schema."""
 
     @classmethod
-    def diagram(cls, view=True):
+    def draw(cls, view=True):
         """Make a diagram of entity relationships."""
-        import biogram
+        import erdiagram
 
         settings = load_or_create_instance_settings()
         engine = settings.db_engine()
         metadata = sql.MetaData(bind=engine)
         metadata.reflect()
-        graph = biogram.create_schema_graph(
+        graph = erdiagram.create_schema_graph(
             metadata=metadata,
             show_datatypes=False,
             show_indexes=False,  # ditto for indexes
@@ -23,13 +23,12 @@ class schema:
             concentrate=False,  # Don't try to join the relation lines together
         )
         if view:
-            biogram.view(graph)
+            erdiagram.view(graph)
         else:
             return graph
 
     @classmethod
-    @property
-    def entities(cls):
+    def list_entities(cls):
         """Return all entities in the db."""
         metadata = sql.MetaData()
         settings = load_or_create_instance_settings()
